From 4ff7439f2322d635b73469496bdedc1c9409bce1 Mon Sep 17 00:00:00 2001
From: Chen Qun <kuhn.chenqun@huawei.com>
Date: Wed, 3 Jun 2020 12:04:13 +0800
Subject: [PATCH 72/77] virsh_domtime: add different cpu_mode for aarch64

For aarch64, different cpu_mode may have different results, when suspend and
managedsave vm.

Signed-off-by: Chen Qun <kuhn.chenqun@huawei.com>
---
 libvirt/tests/cfg/virsh_cmd/domain/virsh_domtime.cfg | 12 ++++++++++++
 libvirt/tests/src/virsh_cmd/domain/virsh_domtime.py  |  7 +++++++
 2 files changed, 19 insertions(+)

diff --git a/libvirt/tests/cfg/virsh_cmd/domain/virsh_domtime.cfg b/libvirt/tests/cfg/virsh_cmd/domain/virsh_domtime.cfg
index e9629828..32093775 100644
--- a/libvirt/tests/cfg/virsh_cmd/domain/virsh_domtime.cfg
+++ b/libvirt/tests/cfg/virsh_cmd/domain/virsh_domtime.cfg
@@ -23,8 +23,20 @@
                     domtime_time = 9223372035
                 - suspend_vm:
                     suspend_vm = yes
+                    variants:
+                        - host_model:
+                            only aarch64
+                            cpu_mode = "host_auto"
+                        - host_passthrough:
+                            cpu_mode = "host-passthrough"
                 - managedsave_vm:
                     managedsave_vm = yes
+                    variants:
+                        - host_model:
+                            only aarch64
+                            cpu_mode = "host_auto"
+                        - host_passthrough:
+                            cpu_mode = "host-passthrough"
                 - pmsuspend_vm:
                     no pseries
                     pmsuspend_vm = yes
diff --git a/libvirt/tests/src/virsh_cmd/domain/virsh_domtime.py b/libvirt/tests/src/virsh_cmd/domain/virsh_domtime.py
index e7f25d09..12ccc673 100644
--- a/libvirt/tests/src/virsh_cmd/domain/virsh_domtime.py
+++ b/libvirt/tests/src/virsh_cmd/domain/virsh_domtime.py
@@ -6,6 +6,7 @@ import platform
 
 from avocado.utils import process
 
+from virttest import cpu
 from virttest import virsh
 from virttest import error_context
 from virttest import utils_time
@@ -348,6 +349,12 @@ def run(test, params, env):
     vm_stop_duration = int(params.get("vm_stop_duration", "10"))
 
     vm_name = params.get("main_vm")
+    cpumodel = params.get("cpu_mode", '')
+    if "host_auto" in cpumodel:
+        cpumodel = cpu.get_cpu_info().get('Model name', None)
+        vm_xml.VMXML.set_cpu_mode(vm_name, mode='host-model', model=cpumodel)
+    else:
+        vm_xml.VMXML.set_cpu_mode(vm_name, mode='host-passthrough')
     vm = env.get_vm(vm_name)
     readonly = (params.get("readonly_test", "no") == "yes")
 
-- 
2.23.0

